@@ -29,14 +29,14 @@ pub struct PackReq {
 /// which is then sent to the server remotely over the network
 #[derive(Debug)]
 pub struct ClientStub {
-    pub timeout: Duration,
+    pub timeout: Option<Duration>,
     pub tag: AtomicU64,
 }
 
 impl ClientStub {
     pub fn new() -> Self {
         Self {
-            timeout: Duration::from_secs(60),
+            timeout: None,
             tag: AtomicU64::new(0),
         }
     }
@@ -71,17 +71,19 @@ impl ClientStub {
             if rsp_frame.id == id {
                 debug!("get response id = {}", id);
                 if rsp_frame.ok == 0 {
-                    let rsp_data = rsp_frame.decode_rsp();
+                    let rsp_data = rsp_frame.get_payload();
                     let resp: String = unsafe { String::from_utf8_unchecked(rsp_data.to_vec()) };
                     return Err(Error { inner: resp });
                 } else {
-                    let rsp_data = rsp_frame.decode_rsp();
+                    let rsp_data = rsp_frame.get_payload();
                     let resp: Resp = codec.decode(rsp_data)?;
                     return Ok(resp);
                 }
             } else {
-                if time.elapsed() > self.timeout {
-                    return Err(err!("rpc call timeout!"));
+                if let Some(timeout) = self.timeout{
+                    if time.elapsed() > timeout {
+                        return Err(err!("rpc call timeout!"));
+                    }
                 }
             }
         }
@@ -114,7 +116,7 @@ impl ServerStub {
             };
             debug!("get request: id={:?}", req.id);
             let mut rsp = ReqBuf::new();
-            let req_data = req.decode_req();
+            let req_data = req.get_payload();
             if let Ok(h) = codec.decode::<PackReq>(&req_data) {
                 let stub = stubs.get(&h.m);
                 if stub.is_none() {
